import { Module } from '@nestjs/common';
import { APP_FILTER, APP_INTERCEPTOR } from '@nestjs/core';
import { TypeOrmModule } from "@nestjs/typeorm";
import { Connection } from "typeorm";

import { AppService } from './app.service';
import { UserModule } from './user/user.module';
import { HttpErrorFilter } from './shared/http-error.filter';
import { LoggingInterceptor } from './shared/logging.interceptor';
import { MapMarkerModule } from './mapmarkers/mapmarkers.module';
import { GameModule } from './game/game.module';



@Module({
  imports: [TypeOrmModule.forRoot(), UserModule, MapMarkerModule, GameModule],
  controllers: [],
  providers: [
    AppService, {
      provide: APP_FILTER,
      useClass: HttpErrorFilter
    },
    {
      provide: APP_INTERCEPTOR,
      useClass: LoggingInterceptor,
    }
  ],
})
export class AppModule {
  constructor(private readonly connection: Connection) {}
}
