import { Injectable, HttpException, HttpStatus } from '@nestjs/common';
import { Repository, In } from "typeorm";
import { InjectRepository } from "@nestjs/typeorm";

import { MapMarkerEntity } from './mapmarker.entity';
import { MapMarkerDTO } from './mapmarker.dto';
import { PersonEntity } from '../user/user.entity';
import { userInfo } from 'os';

@Injectable()
export class MapMarkerService {
    constructor(
        @InjectRepository(MapMarkerEntity) private mapmarkerRepository: Repository<MapMarkerEntity>,
        @InjectRepository(PersonEntity) private personRepository: Repository<PersonEntity>
    ) { }

    // insert markers
    async insertLocation(personId: string, data: MapMarkerDTO) {
        try {
            data.timestamp = new Date(Date.now()).toLocaleString(); //get functions runtime as timestamp
            const user = await this.personRepository.findOne({ where: { id: personId } })
            const location = await this.mapmarkerRepository.create({ ...data, player: user });
            await this.mapmarkerRepository.insert(location);
            return { ...data, player: location.player.nameObject() };
        } catch (error) {
            return error;
        }
    }

    // get all markers
    async getAllMarkers() {
        try {
            const markers = await this.mapmarkerRepository.find({ relations: ['player'] });
            return markers.map(marker => { return { ...marker, player: marker.player.nameObject() } });
        } catch (error) {
            return error.message;
        }

    }
}